@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <glom/application.h>
@@ -87,6 +87,25 @@ void Application::on_activate()
   create_window();
 }
 
+void Application::on_startup()
+{
+  //Call the base class:
+  Gtk::Application::on_startup();
+
+  //TODO: Remove this if there is ever an easier way to make 'accel's from the .glade file just work.
+  //See https://bugzilla.gnome.org/show_bug.cgi?id=708905
+
+  //From window_main.glade:
+  add_accelerator("<Primary>n", "file.new");
+  add_accelerator("<Primary>o", "file.open");
+  add_accelerator("<Primary>w", "win.close");
+  add_accelerator("<Primary>p", "win.print"); //Not in the main window, but in the Relationships Overview window, and maybe others.
+  add_accelerator("<Shift><Primary>p", "win.print-preview"); //Not in the main window, but in the Print Layout window, and maybe others.
+  add_accelerator("<Primary>c", "edit.copy");
+  add_accelerator("<Primary>v", "edit.paste");
+  add_accelerator("<Primary>f", "edit.find");
+}
+
 void Application::on_open(const Gio::Application::type_vec_files& files,
   const Glib::ustring& hint)
 {
@@ -178,7 +197,7 @@ int Application::on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine>
     if(!file->query_exists())
     {
       std::cerr << _("Glom: The file does not exist.") << std::endl;
-      std::cerr << "uri: " << input_uri << std::endl;
+      std::cerr << G_STRFUNC << ": uri: " << input_uri << std::endl;
 
       std::cerr << std::endl << context.get_help() << std::endl;
       return EXIT_FAILURE;
