@@ -2422,7 +2422,8 @@ void Frame_Glom::on_menu_report_selected(const Glib::ustring& report_name)
 
   FoundSet found_set = m_Notebook_Data.get_found_set();
 
-  ReportBuilder report_builder(AppWindow::get_current_locale());
+  //TODO: Find a way to get a full locale name from the simplified locale name from AppWindow::get_current_locale():
+  ReportBuilder report_builder(std::locale("") /* the user's current locale */);
   report_builder.set_document(document);
   const std::string filepath = 
     report_builder.report_build_and_save(found_set, report); //TODO: Use found set's where_clause.
