@@ -887,7 +887,7 @@ static const SECTION union { const guint8 data[7016]; const double alignment; vo
 } };
 
 static GStaticResource static_resource = { libglom_resource_data.data, sizeof (libglom_resource_data.data), NULL, NULL, NULL };
-extern GResource *libglom_get_resource (void);
+G_GNUC_INTERNAL GResource *libglom_get_resource (void);
 GResource *libglom_get_resource (void)
 {
   return g_static_resource_get_resource (&static_resource);
