@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "label.h"
@@ -56,6 +56,8 @@ Label::~Label()
 
 void Label::init()
 {
+  setup_util_menu(this);
+
   add(m_label);
   m_label.show();
   set_events(Gdk::ALL_EVENTS_MASK);
