@@ -141,7 +141,7 @@ void Dialog_GroupBy::on_button_field_sort_by()
   {
     m_dialog_choose_sort_fields->set_fields(m_table_name, m_layout_item->get_fields_sort_by());
 
-    const int response = Glom::Utils::dialog_run_with_help(m_dialog_choose_sort_fields);
+    const int response = Glom::UiUtils::dialog_run_with_help(m_dialog_choose_sort_fields);
     m_dialog_choose_sort_fields->hide();
     if(response == Gtk::RESPONSE_OK && m_dialog_choose_sort_fields->get_modified())
     {
@@ -157,15 +157,18 @@ void Dialog_GroupBy::on_button_secondary_fields()
   if(!m_dialog_choose_secondary_fields)
   {
     Utils::get_glade_widget_derived_with_warning(m_dialog_choose_secondary_fields);
-    add_view(m_dialog_choose_secondary_fields); //Give it access to the document.
-    m_dialog_choose_secondary_fields->set_title(_("Group By - Secondary Fields"));
+    if(m_dialog_choose_secondary_fields)
+    {
+      add_view(m_dialog_choose_secondary_fields); //Give it access to the document.
+      m_dialog_choose_secondary_fields->set_title(_("Group By - Secondary Fields"));
+    }
   }
 
   if(m_dialog_choose_secondary_fields)
   {
     m_dialog_choose_secondary_fields->set_fields(m_table_name, m_layout_item->get_secondary_fields()->m_list_items);
 
-    const int response = Glom::Utils::dialog_run_with_help(m_dialog_choose_secondary_fields);
+    const int response = Glom::UiUtils::dialog_run_with_help(m_dialog_choose_secondary_fields);
     m_dialog_choose_secondary_fields->hide();
     if(response == Gtk::RESPONSE_OK && m_dialog_choose_secondary_fields->get_modified())
     {
