@@ -20,6 +20,8 @@
 
 #include "notebooklabelglom.h"
 #include <glom/appwindow.h>
+#include <gtkmm/menu.h>
+#include <giomm/menu.h>
 #include <glibmm/i18n.h>
 
 #include <iostream>
@@ -53,7 +55,7 @@ void NotebookLabel::init()
   m_label.show();
   set_events (Gdk::ALL_EVENTS_MASK);
   set_visible_window (false);
-  setup_menu();
+  setup_menu(this);
 }
 
 void NotebookLabel::set_label (const Glib::ustring& title)
@@ -107,44 +109,23 @@ void NotebookLabel::on_menu_delete_activate()
   }
 }
 
-void NotebookLabel::setup_menu()
+void NotebookLabel::setup_menu(Gtk::Widget* /* widget */)
 {
-  m_refUIManager = Gtk::UIManager::create();
-  m_refActionGroup = Gtk::ActionGroup::create();
+  m_refActionGroup = Gio::SimpleActionGroup::create();
 
-  m_refActionGroup->add(Gtk::Action::create("NotebookMenu", "Notebook Menu") );
-  m_refNewGroup = Gtk::Action::create("NewGroup", _("New Group"));
-  m_refDelete = Gtk::Action::create("Delete", _("Delete"));
-  
-  m_refActionGroup->add(m_refNewGroup,
+  m_refNewGroup = m_refActionGroup->add_action("new-group",
     sigc::mem_fun(*this, &NotebookLabel::on_menu_new_group_activate) );
-  m_refActionGroup->add(m_refDelete,
+  m_refDelete = m_refActionGroup->add_action("delete",
     sigc::mem_fun(*this, &NotebookLabel::on_menu_delete_activate) );
-    
-  m_refUIManager->insert_action_group(m_refActionGroup);
+ 
+  insert_action_group("context", m_refActionGroup);
 
-  try
-  {
-    Glib::ustring ui_info = 
-        "<ui>"
-        "  <popup name='NotebookMenu'>"
-        "    <menuitem action='NewGroup'/>"
-        "    <separator />"
-        "    <menuitem action='Delete' />"
-        "  </popup>"
-        "</ui>";
+  Glib::RefPtr<Gio::Menu> menu = Gio::Menu::create();
+  menu->append(_("New Group"), "context.new-group");
+  menu->append(_("_Delete"), "context.delete");
 
-    m_refUIManager->add_ui_from_string(ui_info);
-  }
-  catch(const Glib::Error& ex)
-  {
-    std::cerr << "building menus failed: " <<  ex.what();
-  }
-
-  //Get the menu:
-  m_pPopupMenu = dynamic_cast<Gtk::Menu*>( m_refUIManager->get_widget("/NotebookMenu") ); 
-  if(!m_pPopupMenu)
-    g_warning("menu not found");
+  m_pPopupMenu = new Gtk::Menu(menu);
+  m_pPopupMenu->attach_to_widget(*this);
 }
 
 bool NotebookLabel::on_button_press_event(GdkEventButton *event)
