@@ -14,15 +14,15 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
  
 #include <glom/glade_utils.h>
 #include <glom/appwindow.h>
 #include <glom/dialog_existing_or_new.h>
 #include <glom/mode_design/print_layouts/box_print_layouts.h>
-#include <glom/mode_design/relationships_overview/dialog_relationships_overview.h>
+#include <glom/mode_design/relationships_overview/window_relationships_overview.h>
 #include <glom/mode_design/dialog_relationships.h>
 #include <glom/mode_design/report_layout/dialog_layout_report.h>
 #include <glom/box_reports.h>
@@ -87,7 +87,7 @@ bool instantiate_widget()
   Glom::Utils::get_glade_widget_derived_with_warning(widget);
   if(!widget)
   {
-    std::cerr << "Test: Failed to instantiate widget of type: " << typeid(T_Widget).name() << std::endl;
+    std::cerr << G_STRFUNC << ": Test: Failed to instantiate widget of type: " << typeid(T_Widget).name() << std::endl;
     exit(EXIT_FAILURE); //Make sure that our test case fails.
     return false;
   }
@@ -102,10 +102,10 @@ bool instantiate_widget()
   if( (allocation.get_height() > GLOM_MAX_WINDOW_HEIGHT) ||
     (allocation.get_width() > GLOM_MAX_WINDOW_WIDTH))
   {
-    std::cerr << "Test: The window/widget is too big: " << T_Widget::glade_id << std::endl;
-    std::cerr << "  height=" << allocation.get_height() << std::endl; 
-    std::cerr << "  width=" << allocation.get_width() << std::endl;
-    std::cerr << "  (Ignored, though it should be fixed.)" << std::endl; 
+    std::cerr << G_STRFUNC << ": Test: The window/widget is too big: " << T_Widget::glade_id << std::endl;
+    std::cerr << G_STRFUNC << ":   height=" << allocation.get_height() << std::endl; 
+    std::cerr << G_STRFUNC << ":   width=" << allocation.get_width() << std::endl;
+    std::cerr << G_STRFUNC << ":   (Ignored, though it should be fixed.)" << std::endl; 
     //TODO: Uncomment this when all the windows are small enough: exit(EXIT_FAILURE); //Make sure that our test case fails.
   }
   
@@ -136,7 +136,7 @@ int main(int argc, char *argv[])
 
   //Developer mode UI:
   instantiate_widget<Box_Print_Layouts>();
-  instantiate_widget<Dialog_RelationshipsOverview>();
+  instantiate_widget<Window_RelationshipsOverview>();
   instantiate_widget<Dialog_Relationships>();
   instantiate_widget<Dialog_Layout_Report>();
   instantiate_widget<Box_Reports>();
